@@ -1,10 +1,9 @@
-from django.conf import settings
 from django.core.urlresolvers import reverse, NoReverseMatch
 from django.utils.safestring import mark_safe
 
-from layout import Layout, LayoutSlice
-from utils import render_field, flatatt, TEMPLATE_PACK
-from exceptions import FormHelpersException
+from .layout import Layout, LayoutSlice
+from .utils import render_field, flatatt, TEMPLATE_PACK
+from .exceptions import FormHelpersException
 
 
 class DynamicLayoutHandler(object):
