@@ -44,7 +44,7 @@ def render_field(field, form, form_style, context, template=None, labelclass=Non
     FAIL_SILENTLY = getattr(settings, 'CRISPY_FAIL_SILENTLY', True)
 
     if hasattr(field, 'render'):
-        if 'template_pack' in inspect.getargspec(field.render).args:
+        if 'template_pack' in inspect.getargspec(field.render)[0]:
             return field.render(form, form_style, context, template_pack=template_pack)
         else:
             return field.render(form, form_style, context)
